import { Body, Controller, Delete, Get, HttpCode, HttpStatus, Param, Patch, Post, Query } from "@nestjs/common";
import { AlpineiqService } from "./alpineiq.service";
import { CreateAlpineiqDto } from "./dto/create-alpineiq.dto";
import { UpdateAlpineiqDto } from "./dto/update-alpineiq.dto";
import { Constants } from "src/utils/constants";

@Controller({
    path: "alpineiq",
    version: Constants.API_VERSION_1
})
export class AlpineiqController {
    constructor(private readonly alpineiqService: AlpineiqService) {
    }

    @Post("/personas/create")
    @HttpCode(HttpStatus.OK)
    personaCreateNewContact(@Body() dto: CreateAlpineiqDto) {
        return this.alpineiqService.personaCreateNewContact(dto);
    }

    @Get("/personas/all")
    personasFindAll(@Query("retailerId") retailerId: string) {
        return this.alpineiqService.personasFindAll(retailerId);
    }

    @Get("/personas-by-contactid")
    personaByContactID(@Query("retailerId") retailerId: string, @Query("contactId") contactId: string) {
        return this.alpineiqService.personaByContactID(retailerId, contactId);
    }

    @Get("/personas/loyalty/:pii")
    getLoyaltyStatus(@Param("pii") pii: string) {
        return this.alpineiqService.getLoyaltyStatus(pii);
    }

    @Patch(":id")
    update(@Param("id") id: string, @Body() updateAlpineiqDto: UpdateAlpineiqDto) {
        return this.alpineiqService.update(+id, updateAlpineiqDto);
    }

    @Delete(":id")
    remove(@Param("id") id: string) {
        return this.alpineiqService.remove(+id);
    }
}
