import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { ContactUsSectionOneService } from "./contact-us-section-one.service";
import { CreateContactUsSectionOneDto } from "./dto/create-contact-us-section-one.dto";
import { UploadedFiles, UseInterceptors } from "@nestjs/common/decorators";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { UpdateContactUsSectionOneDto } from "./dto/update-contact-us-section-one.dto";

@Controller({ path: "contact-us-section-one", version: Constants.API_VERSION_1 })

export class ContactUsSectionOneController {
    constructor(private readonly service: ContactUsSectionOneService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "icon", maxCount: 1 }
        ]
    ))
    create(
        @Body() dto: CreateContactUsSectionOneDto,
        @UploadedFiles() files: {
            icon: UploadedMulterFileI
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "icon", maxCount: 1 }
        ]
    ))
    update(
        @Param("id") id: string,
        @Body() dto: UpdateContactUsSectionOneDto,
        @UploadedFiles() files: {
            icon: UploadedMulterFileI
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
