import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateEmailNotifierDto } from "./dto/create-email-notifier.dto";
import { UpdateEmailNotifierDto } from "./dto/update-email-notifier.dto";
import { EmailNotifiyee } from "./entity/email-notifier.entity";


@EntityRepository(EmailNotifiyee)
export class EmailNotifierRepository extends Repository<EmailNotifiyee> {


    async createEntity(
        dto: CreateEmailNotifierDto
    ): Promise<EmailNotifiyee | Error> {
        try {
            const entity = this.create(dto);
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }


    async findByFilterQuery(query: any): Promise<EmailNotifiyee[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOnlyEmail(): Promise<EmailNotifiyee[] | Error> {
        try {
            return await this.find({
                select: ["email"],
                where: { role: 2, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<EmailNotifiyee | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }


    async updateEmail(
        id: string,
        dto: UpdateEmailNotifierDto
    ): Promise<EmailNotifiyee | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(EmailNotifiyee)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

}